@@ -23,6 +23,7 @@ use List::MoreUtils 0.423;
 use PDL::Primitive ();
 use PDL::Factor    ();
 use PDL::SV        ();
+use PDL::Stats::Basic ();
 use PDL::StringfiableExtension;
 use Ref::Util qw(is_plain_arrayref is_plain_hashref);
 use Scalar::Util qw(blessed looks_like_number);
@@ -297,9 +298,6 @@ method at (@rest) {
 }
 
 
-# Public methods other than slice() shall be non-lvalue.
-sub select_columns { shift->_select_columns(@_); }
-
 method exists ($col_name) {
     $self->_columns->exists($col_name);
 }
@@ -355,21 +353,6 @@ method set ($indexer, $data) {
 
 method isempty () { $self->nrow == 0; }
 
-# supports negative indices
-method nth_column($index) {
-	failure::index->throw({
-			msg => "requires index",
-			trace => failure->croak_trace
-		}) unless defined $index;
-	failure::index::exists->throw({
-			msg => "column index out of bounds",
-			trace => failure->croak_trace,
-		}) if $index >= $self->number_of_columns;
-	# fine if $index < 0 because negative indices are supported
-	return ($self->_columns->values)[$index];
-}
-
-
 
 method column_names(@rest) {
     my @colnames =
@@ -451,6 +434,21 @@ method column($colname) {
 	return $self->_columns->get( $colname );
 }
 
+# supports negative indices
+method nth_column($index) {
+	failure::index->throw({
+			msg => "requires index",
+			trace => failure->croak_trace
+		}) unless defined $index;
+	failure::index::exists->throw({
+			msg => "column index out of bounds",
+			trace => failure->croak_trace,
+		}) if $index >= $self->number_of_columns;
+	# fine if $index < 0 because negative indices are supported
+	return ($self->_columns->values)[$index];
+}
+
+
 sub _column_validate {
 	my ($self, $name, $data) = @_;
 	if( $name =~ /^\d+$/  ) {
@@ -497,6 +495,82 @@ sub add_column {
 	$self->_columns->push( $name => $data );
 }
 
+
+method copy () { 
+    return ref($self)->new(
+        columns   => $self->names->map( sub { $_ => $self->at($_)->copy } ), 
+        row_names => $self->row_names->copy
+    );
+}
+*clone = \&copy;
+
+
+method summary ($percentiles=[0.25, 0.75]) {
+    if ( List::AllUtils::any { $_ < 0 or $_ > 1 } @$percentiles ) {
+        die "percentiles should all be in the interval [0, 1].";
+    }
+
+    my $class = ref($self);
+    my @pct   = sort { $a <=> $b }
+      List::AllUtils::uniq( ( ( $percentiles->flatten ), 0.5 ) );
+    my %summary = map {
+        my $col = $self->column($_);
+
+        my $count = $col->ngood;
+        if ( $self->is_numeric_column($_) ) {
+            my $average  = $col->average;
+            my $min      = $col->min;
+            my $max      = $col->max;
+            my @pct_data = map { $col->pct($_) } @pct;
+            if ( $col->$_DOES('PDL::DateTime') ) {
+                $_ => PDL::DateTime->new(
+                    [ 0, $average, 0, $min, @pct_data, $max ] )
+                  ->setbadif( pdl( [ 1, 0, 1, 0, ( (0) x @pct ), 0 ] ) );
+            }
+            else {
+                $_ => pdl(
+                    [
+                        $count, $average,  $col->stdv_unbiased,
+                        $min,   @pct_data, $max
+                    ]
+                );
+            }
+        }
+        else {
+            $_ =>
+              pdl( [ $count, ( ("nan") x ( @pct + 4 ) ) ] )->setnantobad();
+        }
+    } $self->names->flatten;
+    return $class->new(
+        columns   => [ map { $_ => $summary{$_} } $self->names->flatten ],
+        row_names => [
+            qw(count mean std min),
+            (
+                map {
+                    my $nof_digits = int( 4 + log($_) / log(10) );
+                    sprintf( "%.${nof_digits}g%%", $_ * 100 );
+                } @pct
+            ),
+            'max'
+        ],
+    );
+}
+
+
+method select_columns (@rest) {
+    my $indexer = indexer_s(@rest);
+    return $self if ( not defined $indexer or $indexer->indexer->length == 0 );
+
+    my $indices      = $self->_cindexer_to_indices($indexer);
+    my $column_names = $self->column_names;
+    return ref($self)->new(
+        columns => $indices->map(
+            sub { $column_names->at($_) => $self->_nth_column($_) }
+        ),
+        row_names => $self->row_names
+    );
+}
+
 # R
 # > iris[c(1,2,3,3,3,3),]
 # PDL
@@ -523,6 +597,40 @@ method select_rows(@rest) {
 }
 
 
+# below lvalue methods are for slice()
+sub _column : lvalue     { my $col = shift->column(@_);     return $col; }
+sub _nth_column : lvalue { my $col = shift->nth_column(@_); return $col; }
+
+classmethod _check_slice_args (@rest) {
+    state $check_labels =
+      Type::Params::compile( Indexer->plus_coercions(IndexerFromLabels) );
+    state $check_indices =
+      Type::Params::compile( Indexer->plus_coercions(IndexerFromIndices) );
+
+    my ( $row_indexer, $column_indexer ) =
+      map {
+        if ( !defined($_) ) {
+            undef;
+        }
+        elsif ( Indexer->check($_) ) {
+            $_;
+        }
+        else {
+            my $p = guess_and_convert_to_pdl($_);
+            ($p->$_DOES('PDL::SV') ? $check_labels : $check_indices)->($p);
+        }
+      } ( @rest > 1 ? @rest : ( undef, $rest[0] ) );
+    return ( $row_indexer, $column_indexer );
+}
+
+method slice(@rest) : lvalue {
+    my ( $rindexer, $cindexer ) = $self->_check_slice_args(@rest);
+    my $new_df = $self->select_rows($rindexer);
+    $new_df = $new_df->select_columns($cindexer);
+    return $new_df;
+}
+
+
 method sample ($n) {
     if ($n > $self->nrow) {
         die "sample size is larger than nrow";
@@ -533,6 +641,29 @@ method sample ($n) {
 }
 
 
+method which (:$bad_to_val=undef, :$ignore_both_bad=true) {
+    my $coordinates = [ 0 .. $self->ncol - 1 ]->map(
+        fun($cidx)
+        {
+            my $column = $self->at( indexer_i( [$cidx] ) );
+            my $both_bad =
+                $self->DOES('Data::Frame::Role::CompareResult')
+              ? $self->both_bad->at( indexer_i( [$cidx] ) )
+              : undef;
+
+            if ( defined $bad_to_val ) {
+                $column = $column->setbadtoval($bad_to_val);
+            }
+
+            my $indices_false = PDL::Primitive::which(
+                defined $both_bad ? ( !$both_bad & $column ) : $column );
+            return $indices_false->unpdl->map( sub { [ $_, $cidx ] } )->flatten;
+        }
+    );
+    return pdl($coordinates);
+}
+
+
 method merge (DataFrame $df) {
     my $class   = ref($self);
     my $columns = [
@@ -566,6 +697,8 @@ method append (DataFrame $df) {
 }
 *rbind = \&append;
 
+
+
 method transform ($func) {
     state $check = Type::Params::compile(
         (
@@ -636,95 +769,6 @@ method split (ColumnLike $factor) {
 }
 
 
-# below lvalue methods are for slice()
-sub _column : lvalue     { my $col = shift->column(@_);     return $col; }
-sub _nth_column : lvalue { my $col = shift->nth_column(@_); return $col; }
-
-method _select_columns (@rest) : lvalue {
-    my $indexer = indexer_s(@rest);
-    return $self if ( not defined $indexer or $indexer->indexer->length == 0 );
-
-    my $indices      = $self->_cindexer_to_indices($indexer);
-    my $column_names = $self->column_names;
-    return ref($self)->new(
-        columns => $indices->map(
-            sub { $column_names->at($_) => $self->_nth_column($_) }
-        ),
-        row_names => $self->row_names
-    );
-}
-
-classmethod _check_slice_args (@rest) {
-    state $check_labels =
-      Type::Params::compile( Indexer->plus_coercions(IndexerFromLabels) );
-    state $check_indices =
-      Type::Params::compile( Indexer->plus_coercions(IndexerFromIndices) );
-
-    my ( $row_indexer, $column_indexer ) =
-      map {
-        if ( !defined($_) ) {
-            undef;
-        }
-        elsif ( Indexer->check($_) ) {
-            $_;
-        }
-        else {
-            my $p = guess_and_convert_to_pdl($_);
-            ($p->$_DOES('PDL::SV') ? $check_labels : $check_indices)->($p);
-        }
-      } ( @rest > 1 ? @rest : ( undef, $rest[0] ) );
-    return ( $row_indexer, $column_indexer );
-}
-
-method slice(@rest) : lvalue {
-    my ( $rindexer, $cindexer ) = $self->_check_slice_args(@rest);
-    my $new_df = $self->select_rows($rindexer);
-    $new_df = $new_df->select_columns($cindexer);
-    return $new_df;
-}
-
-
-method assign ((DataFrame | Piddle) $x) {
-    if ( DataFrame->check($x) ) {
-        unless ( ( $self->shape == $x->shape )->all ) {
-            die "Cannot assign a data frame of different shape.";
-        }
-        for my $name ( $self->names->flatten ) {
-            my $col = $self->at($name);
-            $col .= $x->at($name);
-        }
-    }
-    elsif ( $x->$_DOES('PDL') ) {
-        my @dims = $self->dims;
-
-        unless ( $x->ndims == 1 and $x->dim(0) == $dims[0] * $dims[1]
-            or $x->ndims == 2
-            and $x->dim(0) == $dims[0]
-            and $x->dim(1) == $dims[1] )
-        {
-            die;
-        }
-
-        for my $i ( 0 .. $self->length - 1 ) {
-            $self->_nth_column($i) .=
-              $x->flat->slice( pdl( 0 .. $dims[0] - 1 ) + $i * $dims[1] );
-        }
-    }
-    return $self;
-}
-
-
-method is_numeric_column ($column_name_or_idx) {
-    my $column = $self->at($column_name_or_idx);
-    return $self->_is_numeric_column($column);
-}
-
-sub _is_numeric_column {
-    my ($self, $piddle) = @_;
-    return !is_discrete($piddle);
-}
-
-
 method sort ($by_columns, $ascending=true) {
     return $self->clone if $by_columns->length == 0;
 
@@ -817,35 +861,44 @@ method id () {
 }
 
 
-method copy () { 
-    return ref($self)->new(
-        columns   => $self->names->map( sub { $_ => $self->at($_)->copy } ), 
-        row_names => $self->row_names->copy
-    );
-}
-*clone = \&copy;
-
-
-method which (:$bad_to_val=undef, :$ignore_both_bad=true) {
-    my $coordinates = [ 0 .. $self->ncol - 1 ]->map(
-        fun($cidx)
-        {
-            my $column = $self->at( indexer_i( [$cidx] ) );
-            my $both_bad =
-                $self->DOES('Data::Frame::Role::CompareResult')
-              ? $self->both_bad->at( indexer_i( [$cidx] ) )
-              : undef;
-
-            if ( defined $bad_to_val ) {
-                $column = $column->setbadtoval($bad_to_val);
-            }
-
-            my $indices_false = PDL::Primitive::which(
-                defined $both_bad ? ( !$both_bad & $column ) : $column );
-            return $indices_false->unpdl->map( sub { [ $_, $cidx ] } )->flatten;
+method assign ((DataFrame | Piddle) $x) {
+    if ( DataFrame->check($x) ) {
+        unless ( ( $self->shape == $x->shape )->all ) {
+            die "Cannot assign a data frame of different shape.";
         }
-    );
-    return pdl($coordinates);
+        for my $name ( $self->names->flatten ) {
+            my $col = $self->at($name);
+            $col .= $x->at($name);
+        }
+    }
+    elsif ( $x->$_DOES('PDL') ) {
+        my @dims = $self->dims;
+
+        unless ( $x->ndims == 1 and $x->dim(0) == $dims[0] * $dims[1]
+            or $x->ndims == 2
+            and $x->dim(0) == $dims[0]
+            and $x->dim(1) == $dims[1] )
+        {
+            die;
+        }
+
+        for my $i ( 0 .. $self->length - 1 ) {
+            $self->_nth_column($i) .=
+              $x->flat->slice( pdl( 0 .. $dims[0] - 1 ) + $i * $dims[1] );
+        }
+    }
+    return $self;
+}
+
+
+method is_numeric_column ($column_name_or_idx) {
+    my $column = $self->at($column_name_or_idx);
+    return $self->_is_numeric_column($column);
+}
+
+sub _is_numeric_column {
+    my ($self, $piddle) = @_;
+    return !is_discrete($piddle);
 }
 
 method _compare ($other, $mode) {
@@ -978,6 +1031,7 @@ sub _column_helper {
 	Data::Frame::Column::Helper->new( dataframe => $self );
 }
 
+
 1;
 
 __END__
@@ -992,7 +1046,7 @@ Data::Frame - data frame implementation
 
 =head1 VERSION
 
-version 0.0042_02
+version 0.0042_03
 
 =head1 STATUS
 
@@ -1010,7 +1064,6 @@ This library is current experimental.
                 y => ( sequence(4) >= 2 ) ,
                 x => [ qw/foo bar baz quux/ ],
             ] );
-
     say $df;
     # ---------------
     #     z  y  x
@@ -1021,8 +1074,9 @@ This library is current experimental.
     #  3  4  1  quux
     # ---------------
 
-    say $df->at(0);
-    # [1 2 3 4]
+    say $df->at(0);         # [1 2 3 4]
+    say $df->at(0)->length; # 4
+    say $df->at('x');       # [1 2 3 4]
 
     say $df->select_rows( 3,1 );
     # ---------------
@@ -1089,7 +1143,7 @@ C<HashRef> (sorted with a stringwise C<cmp>).
 
 =back
 
-=head1 METHODS
+=head1 METHODS / BASIC
 
 =head2 string
 
@@ -1097,41 +1151,33 @@ C<HashRef> (sorted with a stringwise C<cmp>).
 
 Returns a string representation of the C<Data::Frame>.
 
-=head2 number_of_columns
+=head2 ncol / length / number_of_columns 
 
+These methods are same,
+
+    # returns Int
+    ncol()
+    length()
     number_of_columns() # returns Int
 
 Returns the count of the number of columns in the C<Data::Frame>.
 
-=head2 ncol
+=head2 nrow / number_of_rows
 
-    ncol()
-
-This is same as C<number_of_columns>.
-
-=head2 length
-
-    length()
-
-This is same as C<number_of_columns>.
-
-=head2 number_of_rows
+These methods are same,
 
+    # returns Int
+    nrow()
     number_of_rows() # returns Int
 
 Returns the count of the number of rows in the C<Data::Frame>.
 
-=head2 nrow
-
-    nrow()
-
-This is same as C<number_of_rows>.
-
 =head2 dims
 
     dims()
 
-Returns the dimensions of the data frame object, in an array of C<($nrow, $ncol)>.
+Returns the dimensions of the data frame object, in an array of
+C<($nrow, $ncol)>.
 
 =head2 shape
 
@@ -1172,13 +1218,24 @@ In-place delete column given by C<$col_name>.
 
 In-place rename columns.
 
-=head2 select_columns
+It can take either, 
 
-    select_columns($indexer) 
+=over 4
 
-Returns a new data frame object which has the columns selected by C<$indexer>.
+=item *
 
-If a given argument is non-indexer, it would coerce it by C<indexer_s()>.
+A hashref of key mappings.
+
+If a keys does not exist in the mappings, it would not be renamed. 
+
+=item *
+
+A coderef which transforms each key.
+
+=back
+
+    $df->rename( { $from_key => $to_key, ... } );
+    $df->rename( sub { $_[0] . 'foo' } );
 
 =head2 set
 
@@ -1192,18 +1249,22 @@ Sets data to column. If C<$col_name> does not exist, it would add a new column.
 
 Returns true if the data frame has no rows.
 
-=head2 nth_columm
+=head2 names / col_names / column_names
 
-    number_of_rows(Int $n) # returns a column
+These methods are same
 
-Returns column number C<$n>. Supports negative indices (e.g., $n = -1 returns
-the last column).
+    # returns ArrayRef
+    names()
+    names( $new_column_names )
+    names( @new_column_names )
 
-=head2 column_names
+    col_names()
+    col_names( $new_column_names )
+    col_names( @new_column_names )
 
-    column_names() # returns an ArrayRef
-
-    column_names( @new_column_names ) # returns an ArrayRef
+    column_names()
+    column_names( $new_column_names )
+    column_names( @new_column_names )
 
 Returns an C<ArrayRef> of the names of the columns.
 
@@ -1211,29 +1272,15 @@ If passed a list of arguments C<@new_column_names>, then the columns will be
 renamed to the elements of C<@new_column_names>. The length of the argument
 must match the number of columns in the C<Data::Frame>.
 
-=head2 col_names
-
-    col_names($new_names)
-
-This is same as C<column_names>.
-
-=head2 names
-
-    names($new_names)
-
-This is same as C<column_names>.
-
 =head2 row_names
 
-    row_names() # returns a PDL
+    # returns a PDL::SV
+    row_names()
+    row_names( Array @new_row_names )
+    row_names( ArrayRef $new_row_names )
+    row_names( PDL $new_row_names )
 
-    row_names( Array @new_row_names ) # returns a PDL
-
-    row_names( ArrayRef $new_row_names ) # returns a PDL
-
-    row_names( PDL $new_row_names ) # returns a PDL
-
-Returns an C<ArrayRef> of the names of the columns.
+Returns an C<PDL::SV> of the names of the rows.
 
 If passed a argument, then the rows will be renamed. The length of the argument
 must match the number of rows in the C<Data::Frame>.
@@ -1244,6 +1291,13 @@ must match the number of rows in the C<Data::Frame>.
 
 Returns the column with the name C<$column_name>.
 
+=head2 nth_column
+
+    number_of_rows(Int $n) # returns a column
+
+Returns column number C<$n>. Supports negative indices (e.g., $n = -1 returns
+the last column).
+
 =head2 add_columns
 
     add_columns( Array @column_pairlist )
@@ -1257,6 +1311,50 @@ Adds all the columns in C<@column_pairlist> to the C<Data::Frame>.
 Adds a single column to the C<Data::Frame> with the name C<$name> and data
 C<$data>.
 
+=head2 copy / clone
+
+These methods are same,
+
+    copy()
+    clone()
+
+Make a deep copy of this data frame object.
+
+=head2 summary
+
+    summary($percentiles=[0.25, 0.75])
+
+Generate descriptive statistics that summarize the central tendency,
+dispersion and shape of a dataset’s distribution, excluding C<BAD> values.
+
+Analyzes numeric datetime columns only. For other column types like
+C<PDL::SV> and C<PDL::Factor> gets only good value count.
+Returns a data frame of the summarized statistics.
+
+Parameters:
+
+=over 4
+
+=item *
+
+C<$percentiles>
+
+The percentiles to include in the output. All should fall between 0 and 1.
+The default is [.25, .75], which returns the 25th, 50th, and 75th
+percentiles (0.5 would be automatically included).
+
+=back
+
+=head1 METHODS / SELECTING AND INDEXING
+
+=head2 select_columns
+
+    select_columns($indexer) 
+
+Returns a new data frame object which has the columns selected by C<$indexer>.
+
+If a given argument is non-indexer, it would coerce it by C<indexer_s()>.
+
 =head2 select_rows
 
     select_rows( Indexer $indexer)
@@ -1275,6 +1373,49 @@ values in the child data frame columns will appear in the parent data frame.
 
 If no indices are given, a C<Data::Frame> with no rows is returned.
 
+=head2 head
+
+    head( Int $n=6 )
+
+If $n ≥ 0, returns a new C<Data::Frame> with the first $n rows of the
+C<Data::Frame>.
+
+If $n < 0, returns a new C<Data::Frame> with all but the last -$n rows of the
+C<Data::Frame>.
+
+See also: R's L<head|https://stat.ethz.ch/R-manual/R-devel/library/utils/html/head.html> function.
+
+=head2 tail
+
+    tail( Int $n=6 )
+
+If $n ≥ 0, returns a new C<Data::Frame> with the last $n rows of the
+C<Data::Frame>.
+
+If $n < 0, returns a new C<Data::Frame> with all but the first -$n rows of the
+C<Data::Frame>.
+
+See also: R's L<tail|https://stat.ethz.ch/R-manual/R-devel/library/utils/html/head.html> function.
+
+=head2 slice
+
+    my $subset1 = $df->slice($row_indexer, $column_indexer);
+
+    # Note that below two cases are different.
+    my $subset2 = $df->slice($column_indexer);
+    my $subset3 = $df->slice($row_indexer, undef);
+
+Returns a new dataframe object which is a slice of the raw data frame.
+
+This method returns an lvalue which allows PDL-like C<.=> assignment for
+changing a subset of the raw data frame. For example,
+
+    $df->slice($row_indexer, $column_indexer) .= $another_df;
+    $df->slice($row_indexer, $column_indexer) .= $piddle;
+
+If a given argument is non-indexer, it would try guessing if the argument
+is numeric or not, and coerce it by either C<indexer_s()> or C<indexer_i()>.
+
 =head2 sample
 
     sample($n)
@@ -1283,25 +1424,30 @@ Get a random sample of rows from the data frame object, as a new data frame.
 
     my $sample_df = $df->sample(100);
 
-=head2 merge
+=head2 which
+
+    which(:$bad_to_val=undef, :$ignore_both_bad=true)
+
+Returns a pdl of C<[[col_idx, row_idx], ...]>, like the output of
+L<PDL::Primitive/whichND>.
+
+=head1 METHODS / MERGE
+
+=head2 merge / cbind
+
+These methods are same,
 
     merge($df)
-
-=head2 cbind
-
     cbind($df)
 
-This is same as C<merge()>.
+=head2 append / rbind
 
-=head2 append
+These methods are same,
 
     append($df)
-
-=head2 rbind
-
     rbind($df)
 
-This is same as C<append()>.
+=head1 METHODS / TRANSFORMATION AND GROUPING
 
 =head2 transform
 
@@ -1316,21 +1462,25 @@ C<$func> can be one of the following,
 
 =item *
 
-A function coderef. It would be applied to all columns.
+A function coderef.
+
+It would be applied to all columns.
 
 =item *
 
-A hashref of C<{ $column_name =E<gt> $coderef, ... }>. It allows to apply
+A hashref of C<{ $column_name =E<gt> $coderef, ... }>
 
-the function to the specified columns. The raw data frame's columns not 
-existing in the hashref be retained unchanged. Hashref keys not yet
-existing in the raw data frame can be used for creating new columns.
+It allows to apply the function to the specified columns. The raw data
+frame's columns not existing in the hashref be retained unchanged. Hashref
+keys not yet existing in the raw data frame can be used for creating new
+columns.
 
 =item *
 
-An arrayref like C<[ $column_name =E<gt> $coderef, ... ]>. In this mode
+An arrayref like C<[ $column_name =E<gt> $coderef, ... ]>
 
-it's similar as the hasref above, but newly added columns would be in order.
+In this mode it's similar as the hasref above, but newly added columns
+would be in order.
 
 =back
 
@@ -1387,49 +1537,6 @@ values in C<$factor>.
 
 Note that C<$factor> does not necessarily to be PDL::Factor.
 
-=head2 slice
-
-    my $subset1 = $df->slice($row_indexer, $column_indexer);
-
-    # Note that below two cases are different.
-    my $subset2 = $df->slice($column_indexer);
-    my $subset3 = $df->slice($row_indexer, undef);
-
-Returns a new dataframe object which is a slice of the raw data frame.
-
-This method returns an lvalue which allows PDL-like C<.=> assignment for
-changing a subset of the raw data frame. For example,
-
-    $df->slice($row_indexer, $column_indexer) .= $another_df;
-    $df->slice($row_indexer, $column_indexer) .= $piddle;
-
-If a given argument is non-indexer, it would try guessing if the argument
-is numeric or not, and coerce it by either C<indexer_s()> or C<indexer_i()>.
-
-=head2 assign
-
-    assign( (DataFrame|Piddle) $x )
-
-Assign another data frame or a piddle to this data frame for in-place change.
-
-C<$x> can be,
-
-=over 4
-
-*A data frame object having the same dimensions and column names as C<$self>.
-*A piddle having the same number of elements as C<$self>.
-
-=back
-
-This method is internally used by the C<.=> operation, below are same,
-
-    $df->assign($x);
-    $df .= $x;
-
-=head2 is_numeric_column
-
-    is_numeric_column($column_name_or_idx)
-
 =head2 sort
 
     sort($by_columns, $ascending=true)
@@ -1458,24 +1565,36 @@ are from the first occurrance of each unique row in the raw data frame.
 
 Compute a unique numeric id for each unique row in a data frame.
 
-=head2 copy 
+=head1 METHODS / OTHERS
 
-    copy()
+=head2 assign
 
-Make a deep copy of this data frame object.
+    assign( (DataFrame|Piddle) $x )
 
-=head2 clone
+Assign another data frame or a piddle to this data frame for in-place change.
 
-    clone()
+C<$x> can be,
 
-This is same as C<copy()>.
+=over 4
 
-=head2 which
+=item *
 
-    which(:$bad_to_val=undef, :$ignore_both_bad=true)
+A data frame object having the same dimensions and column names as C<$self>.
 
-Returns a pdl of C<[[col_idx, row_idx], ...]>, like the output of
-L<PDL::Primitive/whichND>.
+=item *
+
+A piddle having the same number of elements as C<$self>.
+
+=back
+
+This method is internally used by the C<.=> operation, below are same,
+
+    $df->assign($x);
+    $df .= $x;
+
+=head2 is_numeric_column
+
+    is_numeric_column($column_name_or_idx)
 
 =head1 MISCELLANEOUS FEATURES
 
@@ -1495,7 +1614,7 @@ See L<Data::Frame::Partial::Eval>.
 
 =head1 VARIABLES
 
-=head1 doubleformat
+=head2 doubleformat
 
 This is used when stringifying the data frame. Default is C<'%.8g'>.
 
@@ -1511,10 +1630,10 @@ Default is C<undef>, which means no tolerance at all. You can set it like,
 
 =over 4
 
-=item * L<Alt>
-
 =item * L<Data::Frame::Examples>
 
+=item * L<Alt>
+
 =item * L<PDL>
 
 =item * L<R manual: data.frame|https://stat.ethz.ch/R-manual/R-devel/library/base/html/data.frame.html>.
