@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0042_02'; # TRIAL VERSION
+our $VERSION = '0.0042_03'; # TRIAL VERSION
 
 use Safe::Isa;
 use Test2::API qw/context/;
@@ -38,8 +38,7 @@ sub dataframe_is ($$;$@) {
     my ( $got, $exp, $name, @diag ) = @_;
     my $ctx = context();
 
-    # TODO: Make this a package variable.
-    local $Data::Frame::TOLERANCE_REL = 1e-9;
+    local $Data::Frame::TOLERANCE_REL = 1e-8 unless $Data::Frame::TOLERANCE_REL;
 
     unless ( $got->$_DOES('Data::Frame') ) {
         my $gotname = render_ref($got);
@@ -109,7 +108,7 @@ Test2::Tools::DataFrame - Tools for verifying Data::Frame data frames
 
 =head1 VERSION
 
-version 0.0042_02
+version 0.0042_03
 
 =head1 SYNOPSIS
 
